AdjustedHitsAtK
===============

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedHitsAtK
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedHitsAtK.name
      ~AdjustedHitsAtK.synonyms
      ~AdjustedHitsAtK.value_range

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range
